==> v-sim_3.7.2.orig.tar.gz: v_sim-3.7.2/src/extensions/maps.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Damien
	CALISTE, laboratoire L_Sim, (2001-2013)
  
	Adresse mèl :
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant à visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est régi par la licence CeCILL soumise au droit français et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accepté les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Damien
	CALISTE, laboratoire L_Sim, (2001-2013)

	E-mail address:
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at COPYING.
*/
#ifndef MAPS_H
#define MAPS_H

#include "frame.h"

#include <visu_extension.h>
#include <extraFunctions/map.h>

/**
 * VISU_TYPE_GL_EXT_MAPS:
 *
 * return the type of #VisuGlExtMaps.
 *
 * Since: 3.7
 */
#define VISU_TYPE_GL_EXT_MAPS	     (visu_gl_ext_maps_get_type ())
/**
 * VISU_GL_EXT_MAPS:
 * @obj: a #GObject to cast.
 *
 * Cast the given @obj into #VisuGlExtMaps type.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMaps))
/**
 * VISU_GL_EXT_MAPS_CLASS:
 * @klass: a #GObjectClass to cast.
 *
 * Cast the given @klass into #VisuGlExtMapsClass.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMapsClass))
/**
 * VISU_IS_GL_EXT_MAPS:
 * @obj: a #GObject to test.
 *
 * Test if the given @ogj is of the type of #VisuGlExtMaps object.
 *
 * Since: 3.7
 */
#define VISU_IS_GL_EXT_MAPS(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_GL_EXT_MAPS))
/**
 * VISU_IS_GL_EXT_MAPS_CLASS:
 * @klass: a #GObjectClass to test.
 *
 * Test if the given @klass is of the type of #VisuGlExtMapsClass class.
 *
 * Since: 3.7
 */
#define VISU_IS_GL_EXT_MAPS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_GL_EXT_MAPS))
/**
 * VISU_GL_EXT_MAPS_GET_CLASS:
 * @obj: a #GObject to get the class of.
 *
 * It returns the class of the given @obj.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMapsClass))

typedef struct _VisuGlExtMaps        VisuGlExtMaps;
typedef struct _VisuGlExtMapsPrivate VisuGlExtMapsPrivate;
typedef struct _VisuGlExtMapsClass   VisuGlExtMapsClass;

struct _VisuGlExtMaps
{
  VisuGlExtFrame parent;

  VisuGlExtMapsPrivate *priv;
};

struct _VisuGlExtMapsClass
{
  VisuGlExtFrameClass parent;
};

/**
 * visu_gl_ext_maps_get_type:
 *
 * This method returns the type of #VisuGlExtMaps, use
 * VISU_TYPE_GL_EXT_MAPS instead.
 *
 * Since: 3.7
 *
 * Returns: the type of #VisuGlExtMaps.
 */
GType visu_gl_ext_maps_get_type(void);

/**
 * VISU_GL_EXT_MAPS_ID:
 *
 * The id used to identify this extension, see
 * visu_gl_ext_rebuild() for instance.
 */
#define VISU_GL_EXT_MAPS_ID "Maps"

VisuGlExtMaps* visu_gl_ext_maps_new(const gchar *name);
gboolean visu_gl_ext_maps_setGlView(VisuGlExtMaps *maps, VisuGlView *view);

gboolean visu_gl_ext_maps_add(VisuGlExtMaps *maps, VisuMap *map,
                              float prec, ToolShade *shade, ToolColor *color, gboolean alpha);
gboolean visu_gl_ext_maps_remove(VisuGlExtMaps *maps, VisuMap *map);

gboolean visu_gl_ext_maps_setDirty(VisuGlExtMaps *maps, VisuMap *map);
gboolean visu_gl_ext_maps_setPrecision(VisuGlExtMaps *maps, VisuMap *map, float prec);
gboolean visu_gl_ext_maps_setShade(VisuGlExtMaps *maps, VisuMap *map, ToolShade *shade);
gboolean visu_gl_ext_maps_setLineColor(VisuGlExtMaps *maps, VisuMap *map, ToolColor *color);
gboolean visu_gl_ext_maps_setTransparent(VisuGlExtMaps *maps, VisuMap *map, gboolean alpha);

void visu_gl_ext_maps_draw(VisuGlExtMaps *maps);

#endif

==> v-sim_3.8.0.orig.tar.gz: v_sim-3.8.0/src/extensions/maps.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Damien
	CALISTE, laboratoire L_Sim, (2001-2013)
  
	Adresse mèl :
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant à visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est régi par la licence CeCILL soumise au droit français et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accepté les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Damien
	CALISTE, laboratoire L_Sim, (2001-2013)

	E-mail address:
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at COPYING.
*/
#ifndef MAPS_H
#define MAPS_H

#include <visu_extension.h>
#include <extraFunctions/map.h>

/**
 * VISU_TYPE_GL_EXT_MAPS:
 *
 * return the type of #VisuGlExtMaps.
 *
 * Since: 3.7
 */
#define VISU_TYPE_GL_EXT_MAPS	     (visu_gl_ext_maps_get_type ())
/**
 * VISU_GL_EXT_MAPS:
 * @obj: a #GObject to cast.
 *
 * Cast the given @obj into #VisuGlExtMaps type.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMaps))
/**
 * VISU_GL_EXT_MAPS_CLASS:
 * @klass: a #GObjectClass to cast.
 *
 * Cast the given @klass into #VisuGlExtMapsClass.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMapsClass))
/**
 * VISU_IS_GL_EXT_MAPS:
 * @obj: a #GObject to test.
 *
 * Test if the given @ogj is of the type of #VisuGlExtMaps object.
 *
 * Since: 3.7
 */
#define VISU_IS_GL_EXT_MAPS(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_GL_EXT_MAPS))
/**
 * VISU_IS_GL_EXT_MAPS_CLASS:
 * @klass: a #GObjectClass to test.
 *
 * Test if the given @klass is of the type of #VisuGlExtMapsClass class.
 *
 * Since: 3.7
 */
#define VISU_IS_GL_EXT_MAPS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_GL_EXT_MAPS))
/**
 * VISU_GL_EXT_MAPS_GET_CLASS:
 * @obj: a #GObject to get the class of.
 *
 * It returns the class of the given @obj.
 *
 * Since: 3.7
 */
#define VISU_GL_EXT_MAPS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_GL_EXT_MAPS, VisuGlExtMapsClass))

typedef struct _VisuGlExtMaps        VisuGlExtMaps;
typedef struct _VisuGlExtMapsPrivate VisuGlExtMapsPrivate;
typedef struct _VisuGlExtMapsClass   VisuGlExtMapsClass;

struct _VisuGlExtMaps
{
  VisuGlExt parent;

  VisuGlExtMapsPrivate *priv;
};

struct _VisuGlExtMapsClass
{
  VisuGlExtClass parent;

  gboolean (*add)(VisuGlExtMaps *maps, VisuMap *map,
                  float prec, ToolShade *shade,
                  const ToolColor *color, gboolean alpha);

  void (*added)(VisuGlExtMaps *maps, VisuMap *map);
  void (*removed)(VisuGlExtMaps *maps, VisuMap *map);
};

/**
 * visu_gl_ext_maps_get_type:
 *
 * This method returns the type of #VisuGlExtMaps, use
 * VISU_TYPE_GL_EXT_MAPS instead.
 *
 * Since: 3.7
 *
 * Returns: the type of #VisuGlExtMaps.
 */
GType visu_gl_ext_maps_get_type(void);

/**
 * VISU_GL_EXT_MAPS_ID:
 *
 * The id used to identify this extension, see
 * visu_gl_ext_rebuild() for instance.
 */
#define VISU_GL_EXT_MAPS_ID "Maps"

VisuGlExtMaps* visu_gl_ext_maps_new(const gchar *name);

gboolean visu_gl_ext_maps_add(VisuGlExtMaps *maps, VisuMap *map,
                              float prec, ToolShade *shade,
                              const ToolColor *color, gboolean alpha);
gboolean visu_gl_ext_maps_remove(VisuGlExtMaps *maps, VisuMap *map);
void visu_gl_ext_maps_removeAll(VisuGlExtMaps *maps);

gboolean visu_gl_ext_maps_setPrecision(VisuGlExtMaps *maps, VisuMap *map, float prec);
gboolean visu_gl_ext_maps_setShade(VisuGlExtMaps *maps, VisuMap *map, ToolShade *shade);
gboolean visu_gl_ext_maps_setLineColor(VisuGlExtMaps *maps, VisuMap *map,
                                       const ToolColor *color);
gboolean visu_gl_ext_maps_setTransparent(VisuGlExtMaps *maps, VisuMap *map, gboolean alpha);

/**
 * VisuGlExtMapsIter:
 * @maps: the #VisuGlExtMaps object the iterator iters on.
 * @valid: if the iterator is in a valid state.
 * @map: the current #VisuMap object the iterator is on.
 *
 * Structure to iterate over #VisuMap objects stored in a
 * #VisuGlExtMaps object.
 *
 * Since: 3.8
 */
typedef struct _VisuGlExtMapsIter VisuGlExtMapsIter;
struct _VisuGlExtMapsIter
{
  VisuGlExtMaps *maps;
  gboolean valid;
  VisuMap *map;

  /*< private >*/
  GList *next;
};
void visu_gl_ext_maps_iter_new(VisuGlExtMaps *maps, VisuGlExtMapsIter *iter);
void visu_gl_ext_maps_iter_next(VisuGlExtMapsIter *iter);

#endif
